## 0.31.0.20250913 (2025-09-13)

[stubsabot] Bump httplib2 to 0.31.* ([#14698](https://github.com/python/typeshed/pull/14698))

## 0.30.0.20250831 (2025-08-31)

[httplib2] Update to 0.30.* ([#14665](https://github.com/python/typeshed/pull/14665))

## 0.22.0.20250622 (2025-06-22)

[httplib2] Improve stubs (#14249)

## 0.22.0.20250516 (2025-05-16)

Replace `Incomplete | None = None` in third party stubs (#14063)

## 0.22.0.20250401 (2025-04-01)

Add `__all__` part 2 (#13719)

---------

Co-authored-by: Avasam <samuel.06@hotmail.com>

## 0.22.0.20241221 (2024-12-21)

Update to mypy 1.14 (#13272)

## 0.22.0.20240310 (2024-03-10)

Bump mypy to 1.9, add to json.encoder, small fixups (#11549)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

## 0.22.0.2 (2023-07-20)

Add an upstream_repository field to METADATA.toml (#10487)

Closes: #10478

## 0.22.0.1 (2023-03-27)

Add defaults for third-party stubs E-H (#9954)

## 0.22.0.0 (2023-03-22)

[stubsabot] Bump httplib2 to 0.22.* (#9916)

Release: https://pypi.org/pypi/httplib2/0.22.0
Homepage: https://github.com/httplib2/httplib2
Diff: https://github.com/httplib2/httplib2/compare/v0.21.0...v0.22.0

Stubsabot analysis of the diff between the two releases:
 - Total lines of Python code added: 21.
 - Total lines of Python code deleted: 5.

## 0.21.0.5 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 0.21.0.4 (2023-02-15)

Use `typing_extensions.Self` instead of `_typeshed.Self` (#9702)

## 0.21.0.3 (2023-01-18)

Replace `Any` with `Incomplete` in many places (#9558)

## 0.21.0.2 (2022-12-01)

Mark `httplib2` as complete (#9311)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

## 0.21.0.1 (2022-11-09)

Annotate known magic-method return types (#9131)

## 0.21.0.0 (2022-10-30)

[stubsabot] Bump httplib2 to 0.21.* (#9038)

Release: https://pypi.org/pypi/httplib2/0.21.0
Homepage: https://github.com/httplib2/httplib2
Diff: https://github.com/httplib2/httplib2/compare/v0.20.4...v0.21.0

Stubsabot analysis of the diff between the two releases:
 - Total lines of Python code added: 77.
 - Total lines of Python code deleted: 21.

If stubtest fails for this PR:
- Leave this PR open (as a reminder, and to prevent stubsabot from opening another PR)
- Fix stubtest failures in another PR, then close this PR

Note that you will need to close and re-open the PR in order to trigger CI

Co-authored-by: stubsabot <>

## 0.20.4 (2022-03-29)

Remove unneeded `# noqa` comments, fix broken `# noqa` comments (#7561)

## 0.20.2 (2021-12-28)

Use PEP 585 syntax wherever possible (#6717)

## 0.20.1 (2021-11-26)

Add mypy error codes to '# type: ignore' comments (#6379)

## 0.20.0 (2021-11-08)

Update httplib version to 0.20.* (#6256)

## 0.19.1 (2021-10-12)

Add star to all non-0.1 versions (#6146)

